package hu.bme.kszk.kikerdezo

import android.os.Bundle
import android.preference.PreferenceManager
import android.provider.AlarmClock.EXTRA_MESSAGE
import android.util.Log
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.RecyclerView
import com.google.android.material.floatingactionbutton.FloatingActionButton
import hu.bme.kszk.kikerdezo.adapter.Adapter
import hu.bme.kszk.kikerdezo.database.AppDatabase
import hu.bme.kszk.kikerdezo.model.Result
import java.text.SimpleDateFormat
import java.util.*

class QuestionListActivity : AppCompatActivity() {
    private lateinit var questionAdapter: Adapter

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_question_list)

        val labNum = intent.getIntExtra(EXTRA_MESSAGE, -1)

        if(labNum != -1)
            initRecyclerView(labNum)
        else{
            Log.d("FAIL", "Could not get LAB number!");
            val text = "Nem tudtuk betolteni a labor szamat!"
            val duration = Toast.LENGTH_LONG

            val toast = Toast.makeText(applicationContext, text, duration)
            toast.show()
        }

        val btnFinish =  findViewById<FloatingActionButton>(R.id.btnFinish)
        btnFinish.setOnClickListener{
            Log.d("VESZTETTEM", "nem nyomodott meg a finish gomb")
            saveUserScore(labNum)
        }

    }

    private fun saveUserScore(labNum: Int){
        val rvMain: RecyclerView = findViewById(R.id.rvMain)
        val itemCount = rvMain.adapter?.itemCount
        val sp = PreferenceManager.getDefaultSharedPreferences(this)
        var scoreCounter: Int = 0

        val sdf = SimpleDateFormat("dd/M/yyyy hh:mm:ss")
        val currentDate = sdf.format(Date())


        if(itemCount != null) {
            for (i in 0 until itemCount){
                val holder = rvMain.findViewHolderForAdapterPosition(i) as Adapter.QuestionViewHolder
                if(holder.correct == holder.selected){
                    scoreCounter += 1
                }
            }
        }
        val result = Result(
            null,
            labNum,
            sp.getString("USERNAME", "PlayerOne").toString(),
            scoreCounter,
            currentDate
        )
        val dbThread = Thread {
            AppDatabase.getInstanceResult(this@QuestionListActivity).resultsDao().insertResult(result)
        }
        dbThread.start()
        finish()
    }

    private fun initRecyclerView(b: Int) {
        questionAdapter = Adapter(this)
        val rvMain: RecyclerView = findViewById(R.id.rvMain)
        rvMain.adapter = questionAdapter

        AppDatabase.getInstanceQuestion(this@QuestionListActivity).questionDao().getLabQuestion(b).observe(this, { questions ->
            questionAdapter.submitList(questions.shuffled().take(10)) //Nem hittem volna, hogy ennyire konnyu megoldani a random-ot es az elso x elemet XXD
        })

    }
}
